@@ -1,4 +1,3 @@
-import pytest
 
 from pysaleryd.skeleton import main
 
@@ -7,19 +6,14 @@ __copyright__ = "Björn Dalfors"
 __license__ = "MIT"
 
 
-# def test_fib():
-#     """API Tests"""
-#     assert fib(1) == 1
-#     assert fib(2) == 1
-#     assert fib(7) == 13
-#     with pytest.raises(AssertionError):
-#         fib(-10)
-
-
 def test_main(capsys):
     """CLI Tests"""
     # capsys is a pytest fixture that allows asserts against stdout/stderr
     # https://docs.pytest.org/en/stable/capture.html
-    main(["--host", "192.168.1.151", "--port", "3001", "-t", "3"])
+    main(["--host", "192.168.1.151", "--port", "3001", "--listen", "-t", "3"])
     captured = capsys.readouterr()
-    assert True
+    assert not captured.err
+
+    main(["--host", "192.168.1.151", "--port", "3001", "--send", "--key", "MF", "--data", "0"])
+    captured = capsys.readouterr()
+    assert not captured.err
